Skew Kostka numbers associated to a given skew partition.
skewKostkaNumbers(lambda, mu, output = "vector")If output="vector", the function returns a named vector.
This vector is made of the positive skew Kostka numbers
\(K_{\lambda/\mu,\nu}\) and its names encode the partitions \(\nu\).
If ouput="list", the function returns a list. Each element of this
list is a named list with two elements: an integer partition \(\nu\)
in the field named "nu", and the corresponding skew Kostka number
\(K_{\lambda/\mu,\nu}\) in the field named "value". Only the
non-null skew Kostka numbers are provided by this list.
integer partitions defining the skew partition:
lambda is the outer partition and mu is the inner partition
(so mu must be a subpartition of lambda)
the format of the output, either "vector" or
"list"
The skew Kostka number \(K_{\lambda/\mu,\nu}\) is the number of skew semistandard Young tableaux with shape \(\lambda/\mu\) and weight \(\nu\). The weight of a Young tableau is the vector whose \(i\)-th element is the number of occurrences of \(i\) in this tableau.
KostkaNumber, KostkaNumbersWithGivenMu.
skewKostkaNumbers(c(4,2,2), c(2,2))
Run the code above in your browser using DataLab